---
title: <span class="badge object-type-scalar"></span> ZettaFlopsPerSecond
---
# <span class="badge object-type-scalar"></span> ZettaFlopsPerSecond

Computation: ZFLOP/s

## Definition

```python
# Computation: ZFLOP/s
ZettaFlopsPerSecond: typing.Literal["zflops"] = "zflops"
```
